# Tir [![Travis Build Status](https://api.travis-ci.org/kvfi/tir.svg?branch=master)](https://travis-ci.org/kvfi/tir) [![Codacy Badge](https://api.codacy.com/project/badge/Grade/c4d30704fe684b1c861fe9d64fcb45cc)](https://www.codacy.com/manual/kvfi/tir) [![License](https://img.shields.io/github/license/kvfi/tir.svg)](https://github.com/kvfi/tir/blob/master/LICENSE) 
Tir is a minimalist static site generator that focuses on concise information sharing. It offers the tools to compile notes in a structured manner. You can use Tir as a blog or document generator.

## Getting started

To use Tir, you just have to install it using pip:

```bash
pip install tir
```
